MapRequest

Struct MapRequest 

pub struct MapRequest {
    pub keys: Vec<String>,
    pub value: Vec<u8>,
    pub watermark: DateTime<Utc>,
    pub eventtime: DateTime<Utc>,
    pub headers: HashMap<String, String>,
    pub user_metadata: UserMetadata,
    pub system_metadata: SystemMetadata,
}
Incoming request into the map handler of Mapper.

Fields

keys: Vec<String>

Set of keys in the (key, value) terminology of map/reduce paradigm.

value: Vec<u8>

The value in the (key, value) terminology of map/reduce paradigm.

watermark: DateTime<Utc>

watermark represented by time is a guarantee that we will not see an element older than this time.

eventtime: DateTime<Utc>

Time of the element as seen at source or aligned after a reduce operation.

headers: HashMap<String, String>

Headers for the message.

user_metadata: UserMetadata

User metadata for the message.

system_metadata: SystemMetadata

System metadata for the message.