pub struct PutRequest {
pub id: String,
pub payloads: Vec<Payload>,
}Expand description
PutRequest is the request sent to the Store.
Fields
id: StringID is the unique id as provided by the user in the original request. If not provided, it will be a system generated uuid.
payloads: Vec<Payload>Payloads are one or more results generated (could be more than one due to flat-map).