pub struct SideInputServer<T> { /* private fields */ }Expand description
SideInput is the gRPC service for user-defined Side Inputs. It is used to propagate changes in the values of the provided Side Inputs which allows access to slow updated data or configuration without needing to retrieve it during each message processing. Through this service we should should be able to:- (1) Invoke retrieval request for a single Side Input parameter, which in turn should check for updates and return its latest value. (2) Provide a health check endpoint to indicate whether the service is ready to be used.
Implementations
Sourceimpl<T> SideInputServer<T>
impl<T> SideInputServer<T>
pub fn new(inner: T) -> Self
pub fn from_arc(inner: Arc<T>) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> InterceptedService<Self, F>where
F: Interceptor,
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing requests with the given encoding.
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress responses with the given encoding, if the client supports it.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX