pub struct Data {
pub id: String,
pub payloads: Vec<Payload>,
}Expand description
The processed data from the Pipeline to be stored in the Store.
Fields
id: StringThe unique request ID, the result stored in the store will be index using this ID.
payloads: Vec<Payload>FlatMap of results that will be stored in the Store.