Server

Struct Server 

pub struct Server<C> { /* private fields */ }
gRPC server for session reduce service

Implementations

Source

impl<C> Server<C>

pub fn new(creator: C) -> Self

Create a new Server with the given session reduce service

pub async fn start_with_shutdown( self, user_shutdown_rx: Receiver<()>, ) -> Result<(), Box<dyn Error + Send + Sync>>
where C: SessionReducerCreator + Send + Sync + 'static,

Starts the gRPC server. When message is received on the shutdown channel, graceful shutdown of the gRPC server will be initiated.

pub async fn start(self) -> Result<(), Box<dyn Error + Send + Sync>>
where C: SessionReducerCreator + Send + Sync + 'static,

Starts the gRPC server. Automatically registers signal handlers for SIGINT and SIGTERM and initiates graceful shutdown of gRPC server when either one of the signal arrives.