Module grpc_server

Module grpc_server 

Generic gRPC server implementation

This module provides a generic Server struct that can be used by all Numaflow services, eliminating code duplication across different service implementations.

Structs

Server
Generic gRPC server that can handle any service type This eliminates the need for duplicate Server implementations across all service files

Traits

ServerExtras
Trait providing default implementations for common server configuration methods. This trait works with the builder pattern and eliminates boilerplate delegation code.