pub struct Server<T> { /* private fields */ }Expand description
Generic gRPC server that can handle any service type This eliminates the need for duplicate Server implementations across all service files
Implementations
Sourceimpl<T> Server<T>
impl<T> Server<T>
Sourcepub async fn start_with_shutdown<F>(
self,
shutdown_rx: Receiver<()>,
service_builder: F,
) -> Result<(), Box<dyn Error + Send + Sync>>
pub async fn start_with_shutdown<F>( self, shutdown_rx: Receiver<()>, service_builder: F, ) -> Result<(), Box<dyn Error + Send + Sync>>
Starts the gRPC server with a custom service builder function.
When message is received on the shutdown channel, graceful shutdown of the gRPC server will be initiated.
Sourcepub async fn start<F>(
self,
service_builder: F,
) -> Result<(), Box<dyn Error + Send + Sync>>
pub async fn start<F>( self, service_builder: F, ) -> Result<(), Box<dyn Error + Send + Sync>>
Starts the gRPC server with a custom service builder function. Automatically registers signal handlers for SIGINT and SIGTERM and initiates graceful shutdown of gRPC server when either one of the signal arrives.