pub struct Message {
pub keys: Option<Vec<String>>,
pub value: Vec<u8>,
pub tags: Option<Vec<String>>,
}Expand description
Message is the response from the user’s Reducer::reduce.
Fields
keys: Option<Vec<String>>Keys are a collection of strings which will be passed on to the next vertex as is. It can
be an empty collection. It is mainly used in creating a partition in Reducer::reduce.
value: Vec<u8>Value is the value passed to the next vertex.
Tags are used for conditional forwarding.
Implementations
Sourceimpl Message
Represents a message that can be modified and forwarded.
impl Message
Represents a message that can be modified and forwarded.
Sourcepub fn message_to_drop() -> Message
pub fn message_to_drop() -> Message
Marks the message to be dropped by creating a new Message with an empty value and a special “DROP” tag.
Examples
use numaflow::reduce::Message;
let dropped_message = Message::message_to_drop();Trait Implementations
impl StructuralPartialEq for Message